<?php
/**
 * @file
 *
 * Spider FC settings.
 */

/**
 * Calendar table.
 */
function spider_fc_calendars() {
  $form['fieldset_cal_buttons'] = array(
    '#type' => 'fieldset',
  );
  $form['fieldset_cal_buttons']['publish_calendar'] = array(
    '#type' => 'submit',
    '#submit' => array('spider_fc_publish_calendars'),
    '#value' => t('Publish'),
  );
  $form['fieldset_cal_buttons']['unpublish_calendar'] = array(
    '#type' => 'submit',
    '#submit' => array('spider_fc_unpublish_calendars'),
    '#value' => t('Unpublish'),
  );
  $form['fieldset_cal_buttons']['delete_calendar'] = array(
    '#type' => 'submit',
    '#submit' => array('spider_fc_delete_selected_calendar'),
    '#value' => t('Delete'),
    '#attributes' => array('onclick' => 'if (!confirm(Drupal.t("Do you want to delete selected calendars?"))) {return false;}'),
    '#suffix' => l(t('New'), url('admin/settings/spider_fc/calendar/new', array('absolute' => TRUE))),
  );
  $form['fieldset_search_cal_title'] = array(
    '#type' => 'fieldset',
  );
  $form['fieldset_search_cal_title']['search_cal_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Search calendars by title'),
    '#size' => 25,
    '#default_value' => variable_get('spider_fc_search_cal_title', ''),
  );
  $form['fieldset_search_cal_title']['search_cal_button'] = array(
    '#type' => 'submit',
    '#submit' => array('spider_fc_cal_search'),
    '#value' => t('Go'),
  );
  $form['fieldset_search_cal_title']['reset_cal_button'] = array(
    '#type' => 'submit',
    '#value' => t('Reset'),
    '#submit' => array('spider_fc_cal_reset'),
  );
  $header = array(
    theme('table_select_header_cell'),
    array(
      'data' => t('ID'),
      'field' => 'id',
      'sort' => 'asc',
    ),
    array(
      'data' => t('Title'),
      'field' => 'title',
    ),
    array(
      'data' => t('Manage events'),
    ),
    array(
      'data' => t('Published'),
    ),
    array(
      'data' => t('Delete'),
    ),
  );
  $res = pager_query("SELECT id,title,published FROM {spider_fc_calendar_table} WHERE title LIKE '%%" . variable_get('spider_fc_search_cal_title', '') . "%%'" . tablesort_sql($header), $limit = 20);
  $options = array();
  while ($row = db_fetch_array($res)) {
    $cal_id = $row['id'];
    if ((int)$row['published'] == 1) {
      $publish_unpublish_png = 'publish.png';
      $publish_unpublish_function = 'unpublish';
    }
    else {
      $publish_unpublish_png = 'unpublish.png';
      $publish_unpublish_function = 'publish';
    }
    $checkbox = array(
      '#type' => 'checkbox',
      '#id' => 'checkbox' . $cal_id,
      '#name' => 'checkbox' . $cal_id,
    );
    $options[] = array(
      'checkboxes' => drupal_render($checkbox),
      'id' => $row['id'],
      'title' => l($row['title'], url('admin/settings/spider_fc/calendar/edit', array('query' => 'cal_id=' . $cal_id, 'absolute' => TRUE))),
      'manage_events' => l(t('Manage events'), url('admin/settings/spider_fc/calendar/manage_events', array('query' => 'cal_id=' . $cal_id, 'absolute' => TRUE))),
      'published' => '<a href="' . url('admin/settings/spider_fc/' . $publish_unpublish_function, array('query' => 'cal_id=' . $cal_id, 'absolute' => TRUE)) . '"><img src="' . base_path() . drupal_get_path('module', 'spider_fc') . '/images/' . $publish_unpublish_png . '" /></a>',
      'delete' => l(t('Delete'), url('admin/settings/spider_fc/delete', array('query' => 'cal_id=' . $cal_id, 'absolute' => TRUE))),
    );
  }
  $form['fieldset_calendars'] = array(
    '#type' => 'fieldset',
    '#title' => t('Calendars'),
    '#value' => theme('table', $header, $options) . theme('pager'),
  );
  return $form;
}

/**
 * Search in calendars.
 */
function spider_fc_cal_search($form, &$form_state) {
  if ($form_state['values']['search_cal_title'] != '') {
    variable_set('spider_fc_search_cal_title', $form_state['values']['search_cal_title']);
  }
  else {
    variable_set('spider_fc_search_cal_title', '');
  }
  $form_state['redirect'] = url('admin/settings/spider_fc', array('absolute' => TRUE));
}

/**
 * Reset calendars.
 */
function spider_fc_cal_reset($form, &$form_state) {
  variable_set('spider_fc_search_cal_title', '');
  $form_state['redirect'] = url('admin/settings/spider_fc', array('absolute' => TRUE));
}

/**
 * Publish selected calendars.
 */
function spider_fc_publish_calendars($form, &$form_state) {
  if (db_query("SELECT id FROM {spider_fc_calendar_table}")) {
    $result = db_query("SELECT id FROM {spider_fc_calendar_table}");
    $cal_ids_col = array();
    while ($a = db_fetch_array($result)) {
      $cal_ids_col[] = $a['id'];
    }
    $flag = FALSE;
    foreach ($cal_ids_col as $cal_id) {
      if (isset($_POST['checkbox' . $cal_id])) {
        $flag = TRUE;
        db_query("UPDATE {spider_fc_calendar_table} SET published='%d' WHERE id='%d'", 1, $cal_id);
      }
    }
    if ($flag == FALSE) {
      drupal_set_message(t('You must check a calendar.'), 'warning', FALSE);
    }
  }
}

/**
 * Publish calendar.
 */
function spider_fc_publish_calendar() {
  if (isset($_GET['cal_id'])) {
    $cal_id = check_plain($_GET['cal_id']);
  }
  db_query("UPDATE {spider_fc_calendar_table} SET published='%d' WHERE id='%d'", 1, $cal_id);
  drupal_goto(url('admin/settings/spider_fc', array('absolute' => TRUE)));
}

/**
 * Unpublish selected calendars.
 */
function spider_fc_unpublish_calendars($form, &$form_state) {
  if (db_query("SELECT id FROM {spider_fc_calendar_table}")) {
    $result = db_query("SELECT id FROM {spider_fc_calendar_table}");
    $cal_ids_col = array();
    while ($a = db_fetch_array($result)) {
      $cal_ids_col[] = $a['id'];
    }
    $flag = FALSE;
    foreach ($cal_ids_col as $cal_id) {
      if (isset($_POST['checkbox' . $cal_id])) {
        $flag = TRUE;
        db_query("UPDATE {spider_fc_calendar_table} SET published='%d' WHERE id='%d'", 0, $cal_id);
      }
    }
    if ($flag == FALSE) {
      drupal_set_message(t('You must check a calendar.'), 'warning', FALSE);
    }
  }
}

/**
 * Unpublish calendar.
 */
function spider_fc_unpublish_calendar() {
  if (isset($_GET['cal_id'])) {
    $cal_id = check_plain($_GET['cal_id']);
  }
  db_query("UPDATE {spider_fc_calendar_table} SET published='%d' WHERE id='%d'", 0, $cal_id);
  drupal_goto(url('admin/settings/spider_fc', array('absolute' => TRUE)));
}

/**
 * Delete selected calendars.
 */
function spider_fc_delete_selected_calendar($form, &$form_state) {
  if (db_query("SELECT id FROM {spider_fc_calendar_table}")) {
    $result = db_query("SELECT id FROM {spider_fc_calendar_table}");
    $cal_ids_col = array();
    while ($a = db_fetch_array($result)) {
      $cal_ids_col[] = $a['id'];
    }
    $flag = FALSE;
    foreach ($cal_ids_col as $cal_id) {
      if (isset($_POST['checkbox' . $cal_id])) {
        $flag = TRUE;
        db_query("DELETE FROM {spider_fc_calendar_table} WHERE id='%d'", $cal_id);
        db_query("DELETE FROM {spider_fc_events_table} WHERE calendar='%d'", $cal_id);
        drupal_set_message(t('Selected calendars successfully deleted.'), 'status', FALSE);
      }
    }
    if ($flag == FALSE) {
      drupal_set_message(t('You must check a calendar.'), 'warning', FALSE);
    }
  }
}

/**
 * Delete calendar.
 */
function spider_fc_delete_calendar() {
  if (isset($_GET['cal_id'])) {
    $cal_id = check_plain($_GET['cal_id']);
  }
  db_query("DELETE FROM {spider_fc_calendar_table} WHERE id='%d'", $cal_id);
  db_query("DELETE FROM {spider_fc_events_table} WHERE calendar='%d'", $cal_id);
  drupal_goto(url('admin/settings/spider_fc', array('absolute' => TRUE)));
  drupal_set_message(t('Calendar successfully deleted.'), 'status', FALSE);
}

/**
 * Add a new calendar.
 */
function spider_fc_add_calendar() {
  $form = array();
  $form['cal_title'] = array(
    '#prefix' => '<p style="font-size:20px; font-weight:bold;">' . t('Create a new calendar') . '</p>',
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#required' => TRUE,
    '#size' => 20,
  );
  $form['cal_published'] = array(
    '#type' => 'radios',
    '#title' => t('Published'),
    '#default_value' => 1,
    '#options' => array('1' => t('Yes'), '0' => t('No')),
  );
  $form['cal_submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
    '#submit' => array('spider_fc_cal_save'),
  );
  $form['cal_apply'] = array(
    '#type' => 'submit',
    '#value' => t('Apply'),
    '#submit' => array('spider_fc_cal_apply'),
  );
  $form['cal_cancel'] = array(
    '#type' => 'submit',
    '#value' => t('Cancel'),
    '#attributes' => array('onclick' => 'document.getElementById("edit-cal-title").setAttribute("style", "color:rgba(255, 0, 0, 0)");document.getElementById("edit-cal-title").setAttribute("value", "cancel");'),
    '#submit' => array('spider_fc_cal_new_cancel'),
  );
  return $form;
}

/**
 * Save a new calendar.
 */
function spider_fc_cal_save($form, &$form_state) {
  $count = db_result(db_query("SELECT COUNT(*) FROM {spider_fc_calendar_table}"));
  if ($count >= 1) {
    drupal_set_message(t('To add more than one calendar, download the full version on') . ' ' . l(t('drupal.org.'), 'http://drupal.org/project/flash-calendar'), 'error', FALSE);
    $form_state['redirect'] = url('admin/settings/spider_fc', array('absolute' => TRUE));
    return;
  }
  db_query("INSERT INTO {spider_fc_calendar_table} (title, published) VALUES('" . $form_state['values']['cal_title'] . "', '" . $form_state['values']['cal_published'] . "')");
  $form_state['redirect'] = url('admin/settings/spider_fc', array('absolute' => TRUE));
  drupal_set_message(t('Your calendar successfully saved.'), 'status', FALSE);
}

/**
 * Apply a new calendar.
 */
function spider_fc_cal_apply($form, &$form_state) {
  $count = db_result(db_query("SELECT COUNT(*) FROM {spider_fc_calendar_table}"));
  if ($count >= 1) {
    drupal_set_message(t('To add more than one calendar, download the full version on') . ' ' . l(t('drupal.org.'), 'http://drupal.org/project/flash-calendar'), 'error', FALSE);
    $form_state['redirect'] = url('admin/settings/spider_fc', array('absolute' => TRUE));
    return;
  }
  db_query("INSERT INTO {spider_fc_calendar_table} (title, published) VALUES('" . $form_state['values']['cal_title'] . "', '" . $form_state['values']['cal_published'] . "')");
  $id = db_result(db_query("SELECT MAX(id) FROM {spider_fc_calendar_table}"));
  $form_state['redirect'] = url('admin/settings/spider_fc/calendar/edit', array('query' => 'cal_id=' . $id, 'absolute' => TRUE));
  drupal_set_message(t('Your calendar successfully saved.'), 'status', FALSE);
}

/**
 * Cancel a new calendar save.
 */
function spider_fc_cal_new_cancel($form, &$form_state) { 
  $form_state['redirect'] = url('admin/settings/spider_fc', array('absolute' => TRUE));
}

/**
 * Edit calendar.
 */
function spider_fc_edit_calendar() {
  $form = array();
  if (isset($_GET['cal_id'])) {
    $id = check_plain($_GET['cal_id']);
  }
  $value = db_query("SELECT * FROM {spider_fc_calendar_table} WHERE id='%d'", $id);
  $cal = db_fetch_array($value);
  $form['cal_title'] = array(
    '#prefix' => '<p style="font-size:20px; font-weight:bold;">' . t('Edit calendar') . ' ' . $cal->title . '</p>',
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#required' => TRUE,
    '#default_value' => $cal['title'],
    '#size' => 20,
  );
  $form['cal_published'] = array(
    '#type' => 'radios',
    '#title' => t('Published'),
    '#default_value' => $cal['published'],
    '#options' => array('1' => t('Yes'), '0' => t('No')),
  );
  $form['cal_submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
    '#submit' => array('spider_fc_cal_update'),
  );
  $form['cal_apply'] = array(
    '#type' => 'submit',
    '#value' => t('Apply'),
    '#submit' => array('spider_fc_cal_update_apply'),
  );
  $form['cal_cancel'] = array(
    '#type' => 'submit',
    '#value' => t('Cancel'),
    '#attributes' => array('onclick' => 'document.getElementById("edit-cal-title").setAttribute("style", "color:rgba(255, 0, 0, 0)");document.getElementById("edit-cal-title").setAttribute("value", "cancel");'),
    '#submit' => array('spider_fc_cal_update_cancel'),
  );
  return $form;
}

/**
 * Update the calendar.
 */
function spider_fc_cal_update($form, &$form_state) {
  if (isset($_GET['cal_id'])) {
    $id = check_plain($_GET['cal_id']);
  }
  db_query("UPDATE {spider_fc_calendar_table} SET title='%s',published='%d' WHERE id='%d'", $form_state['values']['cal_title'], $form_state['values']['cal_published'], $id);
  $form_state['redirect'] = url('admin/settings/spider_fc', array('absolute' => TRUE));
  drupal_set_message(t('Your calendar successfully updated.'), 'status', FALSE);
}

/**
 * Apply updated calendar.
 */
function spider_fc_cal_update_apply($form, &$form_state) {
  if (isset($_GET['cal_id'])) {
    $id = check_plain($_GET['cal_id']);
  }
  db_query("UPDATE {spider_fc_calendar_table} SET title='%s',published='%d' WHERE id='%d'", $form_state['values']['cal_title'], $form_state['values']['cal_published'], $id);
  $form_state['redirect'] = url('admin/settings/spider_fc/calendar/edit', array('query' => 'cal_id=' . $id, 'absolute' => TRUE));
  drupal_set_message(t('Your calendar successfully updated.'), 'status', FALSE);
}

/**
 * Cancel the calendar save.
 */
function spider_fc_cal_update_cancel($form, &$form_state) {
  $form_state['redirect'] = url('admin/settings/spider_fc', array('absolute' => TRUE));
}
